from datamaestro.definitions import Argument, Data
from datamaestro.data import Generic
from pathlib import Path
from .ir import AdhocDocuments, AdhocTopics, AdhocAssessments


@Argument("path", type=Path)
@Data()
class TrecTopics(AdhocTopics): pass

@Argument("path", type=Path)
@Data()
class TrecAssessments(AdhocAssessments): pass

@Argument("path", type=Path)
@Data()
class TipsterCollection(AdhocDocuments): pass



from pathlib import Path
from datamaestro.data import Generic, Data, Argument
from datamaestro.data.ml import Supervised

@Argument("train", type=Generic)
@Argument("test", type=Generic, required=False)
@Argument("validation", type=Generic, required=False)
@Data("A dataset used for training language models")
class LanguageModelData(Supervised): pass


#!/home/circleci/project/venv/bin/python3

# Author: 
# Contact: grubert@users.sf.net
# Copyright: This module has been placed in the public domain.

"""
man.py
======

This module provides a simple command line interface that uses the
man page writer to output from ReStructuredText source.
"""

import locale
try:
    locale.setlocale(locale.LC_ALL, '')
except:
    pass

from docutils.core import publish_cmdline, default_description
from docutils.writers import manpage

description = ("Generates plain unix manual documents.  " + default_description)

publish_cmdline(writer=manpage.Writer(), description=description)



"""
GloVe is an unsupervised learning algorithm for obtaining vector representations for words.
  Training is performed on aggregated global word-word co-occurrence statistics from a corpus,
  and the resulting representations showcase interesting linear substructures of the word vector space.
"""
# website: http://nlp.stanford.edu/projects/glove/
# license: Public Domain Dedication and License
# abtract: True
# tags:
#   - word embeddings
# papers:
#   technical description: http://nlp.stanford.edu/pubs/glove.pdf
# description: |
  
from datamaestro.definitions import Dataset
from datamaestro.data import Generic
from datamaestro.download import Reference
from datamaestro.download.archive import ZipDownloader
from datamaestro.download.single import FileDownloader
from datamaestro_text.data.embeddings import WordEmbeddingsText

# size: 822M
# statistics:
#   tokens: 6G
#   vocabulary: 400K
#   cased: false
@ZipDownloader("embeddings", "http://nlp.stanford.edu/data/glove.6B.zip")
@Dataset(Generic, id="6b")
def glove_6b(embeddings):
  return { "path": embeddings }

@Reference("data_6b", glove_6b)
@Dataset(WordEmbeddingsText, id="6b.50")
def glove_6b_50(data_6b):
  """Glove 6B - dimension 50"""
  return { "path": data_6b.path / "glove.6B.50d.txt" }

@Reference("data_6b", glove_6b)
@Dataset(WordEmbeddingsText, id="6b.100")
def glove_6b_100(data_6b):
  """Glove 6B - dimension 100"""
  return { "path": data_6b.path / "glove.6B.100d.txt" }

@Reference("data_6b", glove_6b)
@Dataset(WordEmbeddingsText, id="6b.200")
def glove_6b_200(data_6b):
  """Glove 6B - dimension 200"""
  return { "path": data_6b.path / "glove.6B.200d.txt" }

...
@Reference("data_6b", glove_6b)
@Dataset(WordEmbeddingsText, id="6b.300")
def glove_6b_300(data_6b):
  """Glove 6B - dimension 200"""
  return { "path": data_6b.path / "glove.6B.200d.txt" }



@FileDownloader("embeddings", "http://nlp.stanford.edu/data/glove.42B.300d.zip")
@Dataset(Generic, id="42b")
# size: 2.03G
# statistics:
#   cased: true
#   tokens: 42B
#   vocabulary: 2.2M
#   dimension: 300
def glove_42b(embeddings):  
  """Glove embeddings trained on Common Crawl with 42B tokens"""
  return { "path": embeddings }

@FileDownloader("embeddings", "http://nlp.stanford.edu/data/glove.840B.300d.zip")
@Dataset(Generic, id="840b")
# size: 2.03G
# statistics:
#   cased: true
#   tokens: 840G
#   vocabulary: 2.2M
#   dimension: 300
def glove_840b(embeddings):  
  """Glove embeddings trained on Common Crawl with 840B tokens"""
  return { "path": embeddings }



"""TREC AD-HOC datasets and tasks
"""

from datamaestro.data import Generic
from datamaestro.download import Reference
from datamaestro.download.single import FileDownloader, ConcatDownload
from datamaestro.download.links import Links
from datamaestro.stream import TransformList
from datamaestro.stream.compress import Gunzip
from datamaestro.stream.lines import Replace, Filter
from datamaestro.definitions import Data, Argument, Type, DataTasks, DataTags, Dataset

from datamaestro_text.data.trec import TipsterCollection, TrecTopics, TrecAssessments
from datamaestro_text.data.ir import Adhoc

from .tipster import *
from datamaestro_text.config.edu.upenn.ldc.aquaint import aquaint


# --- TREC 1 (1992)

@Links("documents",
  ap88=ap88.path, ap89=ap89.path, fr88=fr88.path, fr89=fr89.path,
  wsj87=wsj87.path, wsj88=wsj88.path, wsj89=wsj89.path,
  wsj90=wsj90.path, wsj91=wsj91.path, wsj92=wsj92.path,
  ziff1=ziff1.path, ziff2=ziff2.path)
@Dataset(TipsterCollection, id="1.documents")
def trec1_documents(documents):
  """TREC-1 to TREC-3 documents (TIPSTER volumes 1 and 2)"""
  return { "path": documents }

@FileDownloader(
  "topics.sgml", "http://trec.nist.gov/data/topics_eng/topics.51-100.gz",
  transforms=TransformList(Gunzip(), Replace(r"Number:(\s+)0", r"Number: \1"))
)
@Dataset(TrecTopics, id="1.topics")
def trec1_topics(topics):
  return { "path": topics, "parts": ["desc"] }

@ConcatDownload(
  "assessments.qrels", "http://trec.nist.gov/data/qrels_eng/qrels.51-100.disk1.disk2.parts1-5.tar.gz",
  transforms=TransformList(Gunzip(), Replace(r"Number:(\s+)0", r"Number: \1"))
)
@Dataset(TrecAssessments, id="1.assessments")
def trec1_assessments(assessments):
  return { "path": assessments }

@Reference("documents", trec1_documents)
@Reference("topics", trec1_topics)
@Reference("assessments", trec1_assessments)
@Dataset(Adhoc, id="1")
def trec1(documents, topics, assessments):
  "Ad-hoc task of TREC 1 (1992)"
  return {
    "documents": documents,
    "topics": topics,
    "assessments": assessments
  }



# --- TREC 2 (1993)


@FileDownloader(
  "topics.sgml", "http://trec.nist.gov/data/topics_eng/topics.101-150.gz",
  transforms=TransformList(Gunzip(), Replace(r"Number:(\s+)0", r"Number: \1"))
)
@Dataset(TrecTopics, id="2.topics")
def trec2_topics(topics):
  return { "path": topics, "parts": ["title", "desc"] }

@ConcatDownload(
  "assessments.qrels", "http://trec.nist.gov/data/qrels_eng/qrels.101-150.disk1.disk2.parts1-5.tar.gz",
  transforms=TransformList(Gunzip(), Replace(r"Number:(\s+)0", r"Number: \1"))
)
@Dataset(TrecAssessments, id="2.assessments")
def trec2_assessments(assessments):
  return { "path": assessments  }

@Reference("documents", trec1_documents)
@Reference("topics", trec2_topics)
@Reference("assessments", trec2_assessments)
@Dataset(Adhoc, id="2")
def trec2(documents, topics, assessments):
  "Ad-hoc task of TREC 2 (1993)"
  return {
    "documents": documents,
    "topics": topics,
    "assessments": assessments
  }




# --- TREC 3 (1994)


@FileDownloader("topics.sgml", "http://trec.nist.gov/data/topics_eng/topics.151-200.gz")
@Dataset(TrecTopics, id="3.topics")
def trec3_topics(topics):
  return { "path": topics, "parts": ["title", "desc"] }

@ConcatDownload(
  "assessments.qrels", "http://trec.nist.gov/data/qrels_eng/qrels.151-200.201-250.disks1-3.all.tar.gz",
  transforms=TransformList(Gunzip(), Filter(r"^(1\d\d|200)\s"))
)
@Dataset(TrecAssessments, id="3.assessments")
def trec3_assessments(assessments):
  return { "path": assessments }

@Reference("documents", trec1_documents)
@Reference("topics", trec3_topics)
@Reference("assessments", trec3_assessments)
@Dataset(Adhoc, id="3")
def trec3(documents, topics, assessments):
  "Ad-hoc task of TREC 3 (1994)"
  return {
    "documents": documents,
    "topics": topics,
    "assessments": assessments
  }



# --- TREC 4 (1995)


@Links("documents",
  ap88=ap88.path, ap89=ap89.path, ap90=ap90.path,
  fr88=fr88.path,
  sjm1=sjm1.path,
  wsj90=wsj90.path, wsj91=wsj91.path, wsj92=wsj92.path,
  ziff2=ziff2.path, ziff3=ziff3.path)
@Dataset(TipsterCollection, id="4.documents")
def trec4_documents(documents):
  """TREC-4 documents"""
  return { "path": documents }

@FileDownloader("topics.sgml", "http://trec.nist.gov/data/topics_eng/topics.201-250.gz")
@Dataset(TrecTopics, id="4.topics")
def trec4_topics(topics):
  return { "path": topics, "parts": ["title", "desc"] }

@ConcatDownload(
  "assessments.qrels", "http://trec.nist.gov/data/qrels_eng/qrels.201-250.disk2.disk3.parts1-5.tar.gz"
)
@Dataset(TrecAssessments, id="4.assessments")
def trec4_assessments(assessments):
  return { "path": assessments, "parts": ["desc"] }

@Reference("documents", trec4_documents)
@Reference("topics", trec4_topics)
@Reference("assessments", trec4_assessments)
@Dataset(Adhoc, id="4")
def trec4(documents, topics, assessments):
  "Ad-hoc task of TREC 4 (1995)"
  return {
    "documents": documents,
    "topics": topics,
    "assessments": assessments
  }



# --- TREC 5 (1995)

@Links("documents",
  ap88=ap88.path, 
  cr1=cr1.path, 
  fr88=fr88.path, fr94=fr94.path,
  ft1=ft1.path,
  wsj90=wsj90.path, wsj91=wsj91.path, wsj9=wsj92.path,
  ziff2=ziff2.path
)
@Dataset(TipsterCollection, id="4.documents")
def trec5_documents(documents):
  """TREC-5 documents"""
  return { "path": documents }

@FileDownloader("topics.sgml", "http://trec.nist.gov/data/topics_eng/topics.251-300.gz")
@Dataset(TrecTopics, id="5.topics")
def trec5_topics(topics):
  return { "path": topics, "parts": ["title", "desc"] }

@ConcatDownload("assessments.qrels", url="http://trec.nist.gov/data/qrels_eng/qrels.251-300.parts1-5.tar.gz")
@Dataset(TrecAssessments, id="5.qrels")
def trec5_assessments(assessments):
  return { "path": assessments }

@Reference("documents", trec5_documents)
@Reference("topics", trec5_topics)
@Reference("assessments", trec5_assessments)
@Dataset(Adhoc, id="5")
def trec5(documents, topics, assessments):
  "Ad-hoc task of TREC 5 (1996)"
  return { "documents": documents, "topics": topics, "assessments": assessments }



# -- TREC 6 (1997)

@Links("documents",
  cr1=cr1.path, 
  fbis1=fbis1.path,
  fr94=fr94.path,
  ft1=ft1.path,
  la8990=la8990.path
)
@Dataset(TipsterCollection, id="4.documents")
def trec6_documents(documents):
  """TREC-5 documents"""
  return { "path": documents }

@FileDownloader("topics.sgml", "http://trec.nist.gov/data/topics_eng/topics.301-350.gz")
@Dataset(TrecTopics, id="6.topics")
def trec6_topics(topics):
  return { "path": topics, "parts": ["title", "desc"] }

@ConcatDownload("assessments.qrels", url="http://trec.nist.gov/data/qrels_eng/qrels.trec6.adhoc.parts1-5.tar.gz")
@Dataset(TrecAssessments, id="6.qrels")
def trec6_assessments(assessments):
  return { "path": assessments }

@Reference("documents", trec6_documents)
@Reference("topics", trec6_topics)
@Reference("assessments", trec6_assessments)
@Dataset(Adhoc, id="6")
def trec6(documents, topics, assessments):
  "Ad-hoc task of TREC 6 (1997)"
  return { "documents": documents, "topics": topics, "assessments": assessments }



# --- TREC 7 (1998)

@Links("documents",
  fbis1=fbis1.path,
  fr94=fr94.path,
  ft1=ft1.path,
  la8990=la8990.path
)
@Dataset(TipsterCollection, id="4.documents")
def trec7_documents(documents):
  """TREC-7 documents"""
  return { "path": documents }


@FileDownloader("topics.sgml", "http://trec.nist.gov/data/topics_eng/topics.351-400.gz")
@Dataset(TrecTopics, id="7.topics")
def trec7_topics(topics):
  return { "path": topics, "parts": ["title", "desc"] }

@ConcatDownload("assessments.qrels", url="http://trec.nist.gov/data/qrels_eng/qrels.trec7.adhoc.parts1-5.tar.gz")
@Dataset(TrecAssessments, id="7.qrels")
def trec7_assessments(assessments):
  return { "path": assessments }

@Reference("documents", trec7_documents)
@Reference("topics", trec7_topics)
@Reference("assessments", trec7_assessments)
@Dataset(Adhoc, id="7")
def trec7(documents, topics, assessments):
  "Ad-hoc task of TREC 3 (1994)"
  return { "documents": documents, "topics": topics, "assessments": assessments }




# --- TREC 8 (1999)

@FileDownloader("topics.sgml", "http://trec.nist.gov/data/topics_eng/topics.401-450.gz")
@Dataset(TrecTopics, id="8.topics")
def trec8_topics(topics):
  return { "path": topics, "parts": ["title", "desc"] }

@ConcatDownload("assessments.qrels", url="https://trec.nist.gov/data/qrels_eng/qrels.trec8.adhoc.parts1-5.tar.gz")
@Dataset(TrecAssessments, id="8.qrels")
def trec8_assessments(assessments):
  return { "path": assessments }

@Reference("documents", trec7_documents)
@Reference("topics", trec8_topics)
@Reference("assessments", trec8_assessments)
@Dataset(Adhoc, id="8")
def trec8(documents, topics, assessments):
  "Ad-hoc task of TREC 8 (1999)"
  return { "documents": documents, "topics": topics, "assessments": assessments }

# --- TREC Robust (2004)

@FileDownloader("topics", "http://trec.nist.gov/data/robust/04.testset.gz")
@Dataset(TrecTopics, id="robust.2004.topics")
def robust2004_topics(topics):
  return { "path": topics, "parts": ["title", "desc"] }

@FileDownloader("assessments.qrels", "http://trec.nist.gov/data/robust/qrels.robust2004.txt")
@Dataset(TrecAssessments, id="robust.2004.qrels")
def robust2004_assessments(assessments):
  return { "path": assessments }

@Reference("documents", trec7_documents)
@Reference("topics", robust2004_topics)
@Reference("assessments", robust2004_assessments)
@Dataset(Adhoc, id="robust.2004")
def robust2004(documents, topics, assessments):
  "Ad-hoc task of TREC Robust (2004)"
  return { "documents": documents, "topics": topics, "assessments": assessments }


# --- TREC Robust (2005)

@FileDownloader("topics", "http://trec.nist.gov/data/robust/05/05.50.topics.txt")
@Dataset(TrecTopics, id="robust.2005.topics")
def robust2005_topics(topics):
  return { "path": topics, "parts": ["title", "desc"] }

@FileDownloader("assessments.qrels", url="http://trec.nist.gov/data/robust/05/TREC2005.qrels.txt")
@Dataset(TrecAssessments, id="robust.2005.qrels")
def robust2005_assessments(assessments):
  return { "path": assessments }

@Reference("documents", aquaint)
@Reference("topics", robust2005_topics)
@Reference("assessments", robust2005_assessments)
@Dataset(Adhoc, id="robust.2005")
def robust2005(documents, topics, assessments):
  "Ad-hoc task of TREC Robust (2005)"
  return { "documents": documents, "topics": topics, "assessments": assessments }



# --- Task and types definitions

import unittest

from datamaestro.test import DatasetTests
from datamaestro_text import Repository
from datamaestro import Context

class MainTest(DatasetTests, unittest.TestCase):
    pass        

if __name__ == '__main__':
    unittest.main()




#!/home/circleci/project/venv/bin/python3

# $Id: rst2s5.py 4564 2006-05-21 20:44:42Z wiemann $
# Author: Chris Liechti <cliechti@gmx.net>
# Copyright: This module has been placed in the public domain.

"""
A minimal front end to the Docutils Publisher, producing HTML slides using
the S5 template system.
"""

try:
    import locale
    locale.setlocale(locale.LC_ALL, '')
except:
    pass

from docutils.core import publish_cmdline, default_description


description = ('Generates S5 (X)HTML slideshow documents from standalone '
               'reStructuredText sources.  ' + default_description)

publish_cmdline(writer_name='s5', description=description)



from pathlib import Path
from datamaestro.data import File, Data, Argument
import numpy as np

@Argument("encoding", str, ignored=True, default="utf-8")
@Data(description="Word embeddings as a text word / values")
class WordEmbeddingsText(File):
    def load(self):
        words = {}
        vectors = []
        dimension = None
        with self.path.open("rt", encoding=self.encoding) as fp:
            for ix, line in enumerate(fp):
                word, *values = line.split(" ")
                vectors.append([float(x) for x in values])
                if dimension is None:
                    dimension = len(values)
                else:
                    assert dimension == len(values)
                words[word] = ix
        return words, np.matrix(vectors)



"""

TIPSTER is sometimes also called the Text Research Collection Volume or TREC.

The TIPSTER project was sponsored by the Software and Intelligent Systems Technology 
Office of the Advanced Research Projects Agency (ARPA/SISTO) in an effort to significantly 
advance the state of the art in effective document detection (information retrieval) and 
data extraction from large, real-world data collections.

The detection data is comprised of a test collection built at NIST for the TIPSTER project 
and the related TREC project. The TREC project has many other participating information 
retrieval research groups, working on the same task as the TIPSTER groups, but meeting 
once a year in a workshop to compare results (similar to MUC). The test collection consists 
of three CD-ROMs of SGML encoded documents distributed by LDC plus queries and answers 
(relevant documents) distributed by NIST.
"""

from datamaestro.data import Generic
from datamaestro_text.data.trec import TipsterCollection
from datamaestro.download.manual import LinkFolder
from datamaestro.definitions import Data, Argument, Type, DataTasks, DataTags, Dataset

TIPSTER = Dataset(TipsterCollection, url="https://catalog.ldc.upenn.edu/LDC93T3A")

@LinkFolder("documents", "AP88", ["%TIPSTER_DATADIR%", "%TIPSTER_DATADIR%/AP"])
@TIPSTER
def ap88(documents):
  """Associated Press document collection (1988)"""
  return { "path": documents }

@LinkFolder("documents", "AP89", ["%TIPSTER_DATADIR%", "%TIPSTER_DATADIR%/AP"])
@TIPSTER
def ap89(documents):
  """Associated Press document collection (1989)"""
  return { "path": documents }

@LinkFolder("documents", "AP90", ["%TIPSTER_DATADIR%", "%TIPSTER_DATADIR%/AP"])
@TIPSTER
def ap90(documents):
  """Associated Press document collection (1990)"""
  return { "path": documents }


@LinkFolder("documents", "DOE1", ["%TIPSTER_DATADIR%", "%TIPSTER_DATADIR%/DOE"])
@TIPSTER
def doe1(documents):
  """Department of Energy documents"""
  return { "path": documents }



# --- Wall Street Journal (1987-92)

@LinkFolder("documents", "1987", ["%TIPSTER_DATADIR%", "%TIPSTER_DATADIR%/WSJ"])
@TIPSTER
def wsj87(documents):
  """Wall Street Journal (1987)"""
  return { "path": documents }

@LinkFolder("documents", "1988", ["%TIPSTER_DATADIR%", "%TIPSTER_DATADIR%/WSJ"])
@TIPSTER
def wsj88(documents):
  """Wall Street Journal (1988)"""
  return { "path": documents }

@LinkFolder("documents", "1989", ["%TIPSTER_DATADIR%", "%TIPSTER_DATADIR%/WSJ"])
@TIPSTER
def wsj89(documents):
  """Wall Street Journal (1989)"""
  return { "path": documents }

@LinkFolder("documents", "1990", ["%TIPSTER_DATADIR%", "%TIPSTER_DATADIR%/WSJ"])
@TIPSTER
def wsj90(documents):
  """Wall Street Journal (1990)"""
  return { "path": documents }

@LinkFolder("documents", "1991", ["%TIPSTER_DATADIR%", "%TIPSTER_DATADIR%/WSJ"])
@TIPSTER
def wsj91(documents):
  """Wall Street Journal (1991)"""
  return { "path": documents }

@LinkFolder("documents", "1992", ["%TIPSTER_DATADIR%", "%TIPSTER_DATADIR%/WSJ"])
@TIPSTER
def wsj92(documents):
  """Wall Street Journal (1992)"""
  return { "path": documents }


# --- Federal Register (1988-89)


@LinkFolder("documents", "FR88", ["%TIPSTER_DATADIR%", "%TIPSTER_DATADIR%/FR"])
@TIPSTER
def fr88(documents):
  """Federal Register (1988)"""
  return { "path": documents }

@LinkFolder("documents", "FR89", ["%TIPSTER_DATADIR%", "%TIPSTER_DATADIR%/FR"])
@TIPSTER
def fr89(documents):
  """Federal Register (1989)"""
  return { "path": documents }

@LinkFolder("documents", "FR94", ["%TIPSTER_DATADIR%", "%TIPSTER_DATADIR%/FR"])
@TIPSTER
def fr94(documents):
  """Federal Register (1994)"""
  return { "path": documents }


# # ZIFF (1988-92)


@LinkFolder("documents", "ZIFF1", ["%TIPSTER_DATADIR%", "%TIPSTER_DATADIR%/ZIFF"])
@TIPSTER
def ziff1(documents):
  """Ziff/Davis document collection"""
  return { "path": documents }

@LinkFolder("documents", "ZIFF2", ["%TIPSTER_DATADIR%", "%TIPSTER_DATADIR%/ZIFF"])
@TIPSTER
def ziff2(documents):
  """ Ziff/Davis document collection (1989-90)"""
  return { "path": documents }

@LinkFolder("documents", "ZIFF3", ["%TIPSTER_DATADIR%", "%TIPSTER_DATADIR%/ZIFF"])
@TIPSTER
def ziff3(documents):
  """ Ziff/Davis document collection (1991-92)"""
  return { "path": documents }

# # SJM1


@LinkFolder("documents", "SJM1", ["%TIPSTER_DATADIR%", "%TIPSTER_DATADIR%/SJM"])
@TIPSTER
def sjm1(documents):
  """San Jose Mercury News (1991)"""
  return { "path": documents }

# # CR1
@LinkFolder("documents", "CR1", ["%TIPSTER_DATADIR%", "%TIPSTER_DATADIR%/SJM"])
@TIPSTER
def cr1(documents):
  """TODO"""
  return { "path": documents }

# # FT1
@LinkFolder("documents", "FT1", ["%TIPSTER_DATADIR%"])
@TIPSTER
def ft1(documents):
  """Financial Times"""
  return { "path": documents }

# # FBIS1
@LinkFolder("documents", "FBIS", ["%TIPSTER_DATADIR%"])
@TIPSTER
def fbis1(documents):
  """TODO"""
  return { "path": documents }
# ---
# # FBIS1
@LinkFolder("documents", "LATIMES", ["%TIPSTER_DATADIR%"])
@TIPSTER
def la8990(documents):
  """Los Angeles Times (1989-90)"""
  return { "path": documents }



import os
from pathlib import Path
import re
import sys
try:
    from setuptools import setup, find_namespace_packages
except ImportError:
    print("Please upgrade pip: find_namespace_packages not found")
    sys.exit(1)
from setuptools.command.install import install

# Date-based versioning
VERSION='2019.12.16'

RE_BLANCK=re.compile(r"^\s*(#.*)?$")
with (Path(__file__).parent / 'requirements.txt').open() as f:
    requirements = [x for x in f.read().splitlines() if not RE_BLANCK.match(x)]

class VerifyVersionCommand(install):
    """Custom command to verify that the git tag matches our version"""
    description = 'verify that the git tag matches our version'

    def run(self):
        tag = os.getenv('CIRCLE_TAG')

        if tag != VERSION:
            info = "Git tag: {0} does not match the version of this app: {1}".format(
                tag, VERSION
            )
            sys.exit(info)

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name='datamaestro_text',
    version=VERSION,
    description='Text related datasets',
    author='Benjamin Piwowarski',
    author_email='benjamin@piwowarski.fr',
    url='https://github.com/bpiwowar/datamaestro_texts',
    license='MIT',
    python_requires='>=3.5',
    packages=find_namespace_packages(include="datamaestro_text.*"),
    long_description=long_description,
    long_description_content_type="text/markdown",

    install_requires=requirements,
    classifiers=[
        'Intended Audience :: Developers',
        'Intended Audience :: Information Technology',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3 :: Only',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7'
    ],
    entry_points={
        'datamaestro.repositories': [
            'text = datamaestro_text:Repository'
        ]
    },
    cmdclass={
        'verify': VerifyVersionCommand,
    },
    test_suite='datamaestro_text.test'
)



from pathlib import Path
from datamaestro.definitions import Data, Argument, DataTasks, DataTags

@Data(description="IR documents")
class AdhocDocuments(): pass

@Data(description="IR topics")
class AdhocTopics(): pass

@Data(description="IR assessments")
class AdhocAssessments(): pass

@Argument("documents", type=AdhocDocuments)
@Argument("topics", type=AdhocTopics)
@Argument("assessments", type=AdhocAssessments)
@DataTasks("information retrieval")
@Data()
class Adhoc(): pass


from datamaestro.data.ml import FolderBased, Supervised
from datamaestro.definitions import  DataTasks, DataTags, Dataset
from datamaestro.download.archive import TarDownloader

@TarDownloader("data", "http://ai.stanford.edu/~amaas/data/sentiment/aclImdb_v1.tar.gz")
@Dataset(Supervised, url="http://ai.stanford.edu/~amaas/data/sentiment/", id="")
def aclimdb(data):
  """Large Movie Review Dataset

  Paper http://ai.stanford.edu/~amaas/papers/wvSent_acl2011.pdf
  """
  return {
    "train": FolderBased(path=data / "train", classes=["pos", "neg"]),
    "test": FolderBased(path=data / "test", classes=["pos", "neg"])
  }


import logging
from datamaestro.files import File

class CoNLL_U(File):

    def data(self):
        try:
            from conllu import parse
        except:
            logging.error("conllu python module not installed")
            raise 

        with self.path.open("r", encoding="utf-8") as data_file:
            return parse(data_file.read())

    def __iter__(self):
        try:
            from conllu import parse_incr
        except:
            logging.error("conllu python module not installed")
            raise 

        with self.path.open("r", encoding="utf-8") as data_file:
            for tokenlist in parse_incr(data_file):
                yield tokenlist



from pathlib import Path
import http.client
import time
import logging
import zipfile
from tqdm import tqdm
import hashlib
import shutil
from collections import namedtuple

from datamaestro.download import Download
from datamaestro import DatasetDefinition
from datamaestro.utils import TemporaryDirectory

APIKEY_KEY = "org.themoviedb.apikey"

class Handler(Download):
    """Download using the TMDB API"""
    def __init__(self, dataset: DatasetDefinition, definition):
        super().__init__(dataset, definition)
        self.apikey = self.repository.context.preference(APIKEY_KEY)
        self.reset = 0
        self.remaining = 1
    
    def path(self, destination: Path):
        return destination.with_suffix(".zip")

    def retrieve(self, movieId):
        """Retrieves movie information in JSON (as a string) format"""


        while True:
            conn = http.client.HTTPSConnection("api.themoviedb.org")
            if self.reset >= time.time() and self.remaining == 0:
                logging.info("Waiting %.0f seconds", self.reset - time.time())
                time.sleep(self.reset - time.time())
            else:
                conn.request("GET", "/3/movie/%s?language=en-US&api_key=%s" % (movieId, self.apikey), "{}")
                res = conn.getresponse()
                self.reset = float(res.headers["x-ratelimit-reset"])
                self.remaining = int(res.headers["x-ratelimit-remaining"])
                if res.code == 200:
                    return res.read()
                if res.code == 401:
                    raise Exception("Unauthorized: add the api key in the preference file [{}]".format(APIKEY_KEY))
                if res.code == 403:
                    self.reset = float(res.headers["Retry-After"])
                    self.remaining = 0
                    logging.warn("Code a 403 code from the movie DB: retrying after %s", self.reset)
                elif res.code == 404:
                    return None

                raise Exception("Error code not handled: %d" % (res.code))



class MovieLens(Handler):
    def download(self, destination: Path):
        parent = self.dataset.parent

        cachepath = self.context.cachepath /  (hashlib.sha256(self.dataset.id.encode("utf-8")).hexdigest() + ".zip")
        logging.info("Retrieve items from moviedb.org (cache: %s)", cachepath)

        with zipfile.ZipFile(cachepath, mode="a", compression=zipfile.ZIP_DEFLATED) as z:
            # Retrieve already downloaded items from Zip file
            done = set()
            for info in z.infolist():
                done.add(info.filename)
            if done:
                logging.info("Retrieved %d items from cache", len(done))

            # Gather items to download
            Item = namedtuple('Item', ["tmdbId", "movieId"])
            logging.debug("Reading the movie IDs to download")
            items = []
            with (parent.datadir / "links.csv").open("r") as fp:           
                header = {x: i for i, x in enumerate(fp.readline().strip().split(","))}
                tmbdIx = header["tmdbId"]
                movieIx = header["movieId"]

                for line in fp:
                    fields = line.strip().split(",")
                    movieId = fields[movieIx]
                    if not movieId in done:
                        items.append(Item(movieId=movieId, tmdbId=fields[tmbdIx]))

            # Download from Movie DB
            logging.info("Downloading from movie DB")
            for item in tqdm(items):
                data = self.retrieve(item.tmdbId)
                if data is not None:
                    z.writestr(item.movieId, data)

        shutil.move(cachepath, self.path(destination))